import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_selection_route.dart';
import 'package:cramr_ui_lib/widgets/cardinality_selection_panel.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:provider/provider.dart';

import 'settings_controller.dart';

/// Displays the various settings that can be customized by the user.
///
/// When a user changes a setting, the SettingsController is updated and
/// Widgets that listen to the SettingsController are rebuilt.
class SettingsView extends StatelessWidget {
  const SettingsView({Key? key, required this.controller}) : super(key: key);

  static const routeName = '/settings';

  final SettingsController controller;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        leading: IconButton(
          key: const Key('settingsBackButton'),
          icon: const Icon(Icons.arrow_back),
          onPressed: () {
            if (controller.cardinalitySelection.isDirty) {
              final VerbTestModel testModel =
                  Provider.of<VerbTestModel>(context, listen: false);
              testModel.reset();
              Navigator.restorablePopAndPushNamed(
                  context, VerbSelectionRoute.routeName);
              controller.cardinalitySelection.clearDirty();
            } else {
              Navigator.pop(context);
            }
          },
        ),
        title: const Text('Instellingen'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16),
        // Glue the SettingsController to the theme selection DropdownButton.
        //
        // When a user selects a theme from the dropdown list, the
        // SettingsController is updated, which rebuilds the MaterialApp.
        child: Column(
          children: [
            Row(
              children: [
                SizedBox(
                    child: const Icon(FontAwesomeIcons.palette),
                    width: _deviceQuarterWidth(context)),
                SizedBox(
                  height: 50,
                  width: 200,
                  child: ListTile(
                    leading: DropdownButton<ThemeMode>(
                      key: const Key('screenModeDropdown'),
                      // Read the selected themeMode from the controller
                      value: controller.themeMode,
                      // Call the updateThemeMode method any time the user selects a theme.
                      onChanged: controller.updateThemeMode,
                      items: const [
                        DropdownMenuItem(
                          key: Key('systemMode'),
                          value: ThemeMode.system,
                          child: Text('Telefoon kleuren', key: ValueKey(1)),
                        ),
                        DropdownMenuItem(
                          key: Key('lightMode'),
                          value: ThemeMode.light,
                          child: Text('Lichte kleuren', key: ValueKey(2)),
                        ),
                        DropdownMenuItem(
                          key: Key('darkMode'),
                          value: ThemeMode.dark,
                          child: Text('Donkere kleuren', key: ValueKey(3)),
                        )
                      ],
                    ),
                  ),
                ),
              ],
            ),
            const Divider(),
            Row(
              children: [
                SizedBox(
                    child: const Icon(FontAwesomeIcons.filter),
                    width: _deviceQuarterWidth(context)),
                CardinalitySelectionPanel(controller),
              ],
            )
          ],
        ),
      ),
    );
  }

  double _deviceQuarterWidth(BuildContext context) {
    return MediaQuery.of(context).size.width * 0.25;
  }
}
