import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/widgets/text_checker.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'expected_row.dart';

/// Stateful widget that allows to browse through an indicative and in the
/// mean time write down the form for practice purposes.
class WrittenIndicativeStudyWidget extends StatefulWidget {
  const WrittenIndicativeStudyWidget({Key? key}) : super(key: key);

  @override
  State<WrittenIndicativeStudyWidget> createState() =>
      WrittenIndicativeStudyWidgetState();
}

/// The state to maintain is the person of the indicative that is currently
/// being displayed. This widget is tightly coupled to the Provider framework.
class WrittenIndicativeStudyWidgetState
    extends State<WrittenIndicativeStudyWidget> {
  int _currentPerson = 0;

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Column(
        children: [
          ExpectedRow(currentPerson: _currentPerson),
          TextChecker(currentPerson: _currentPerson, key: UniqueKey()),
          IconButton(
              key: const Key('nextPersonKey'),
              onPressed: () {
                setState(() {
                  _currentPerson = ++_currentPerson % _numberOfItems(context);
                });
              },
              icon: const Icon(Icons.arrow_forward)),
        ],
      ),
      elevation: 15,
    );
  }

  int _numberOfItems(BuildContext context) {
    return Provider.of<VerbTestModel>(context, listen: false).items.length;
  }
}
